==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>IsoProject</name>
    <message>
        <source>Reference point</source>
        <translatorcomment>--exact match--
--file: Edit_pt.ts--
Indique o ponto de referência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation type="obsolete">Ponto de referência</translation>
    </message>
    <message>
        <source>Target point</source>
        <translatorcomment>--google--
Indique o ponto de destino</translatorcomment>
        <translation type="obsolete">Ponto de destino</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
Projeção &amp;Isométrica</translatorcomment>
        <translation>Projeção &amp;isométrica</translation>
    </message>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Deposita ao fim da garimpagem
Centro acima</translatorcomment>
        <translation>Topo</translation>
    </message>
    <message>
        <source>ProjectionType</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">ProjectionType</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita abaixo
Em baixo à direita
Centro abaixo</translatorcomment>
        <translation>Fundo</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Left back</source>
        <translation>Esquerda trás</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita ao meio
Direita abaixo
Em baixo à direita</translatorcomment>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Direita trás</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Rotacione anti-horário antes de projeção</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Rotacione no sentido horário antes de projeção</translation>
    </message>
    <message>
        <source>Rotate counter-clockwise</source>
        <translation type="obsolete">Rotacione anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Rotacione horário</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Projeção escala para o tamanho original</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Escala verdadeira</translation>
    </message>
    <message>
        <location line="-114"/>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Esquerda acima
Em cima à esquerda
Esquerda ao meio</translatorcomment>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Front</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Envie para &amp;frente
Traga para &amp;frente
Traz para a frente
Traz entidades para a frente de outras entidades</translatorcomment>
        <translation type="obsolete">Frontal</translation>
    </message>
    <message>
        <source>Back</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Anterior
Retorna ao último menu</translatorcomment>
        <translation type="obsolete">Trás</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>IsoProject</name>
    <message>
        <source>Reference point</source>
        <translatorcomment>--exact match--
--file: Edit_pt.ts--
Indique o ponto de referência
Copie entidade com ponto de referência  para o clipboard</translatorcomment>
        <translation type="obsolete">Ponto de referência</translation>
    </message>
    <message>
        <source>Target point</source>
        <translatorcomment>--google--
Indique o ponto de destino</translatorcomment>
        <translation type="obsolete">Ponto de destino</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
Projeção &amp;Isométrica</translatorcomment>
        <translation>Projeção &amp;isométrica</translation>
    </message>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Deposita ao fim da garimpagem
Centro acima</translatorcomment>
        <translation>Superior</translation>
    </message>
    <message>
        <source>ProjectionType</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">ProjectionType</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita abaixo
Em baixo à direita
Centro abaixo</translatorcomment>
        <translation>Inferior</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Left back</source>
        <translation>Esquerda atrás</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Direita ao meio
Direita abaixo
Em baixo à direita</translatorcomment>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Direita atrás</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Rotacione a seleção no sentido anti-horário antes de projetar</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Rotacione a seleção no sentido horário antes de projetar</translation>
    </message>
    <message>
        <source>Rotate counter-clockwise</source>
        <translation type="obsolete">Rotacione anti-horário</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Rotacione horário</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Escalone a projeção para o tamanho original (&quot;desenho isométrico&quot;)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Escala verdadeira</translation>
    </message>
    <message>
        <location line="-114"/>
        <source>Left</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Esquerda acima
Em cima à esquerda
Esquerda ao meio</translatorcomment>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Front</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Envie para &amp;frente
Traga para &amp;frente
Traz para a frente
Traz entidades para a frente de outras entidades</translatorcomment>
        <translation type="obsolete">Frontal</translation>
    </message>
    <message>
        <source>Back</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Anterior
Retorna ao último menu</translatorcomment>
        <translation type="obsolete">Trás</translation>
    </message>
</context>
</TS>
